@@ -20,8 +20,9 @@ Geom <- proto(TopLevel, expr={
 
   draw <- function(...) {}
   draw_groups <- function(., data, scales, coordinates, ...) {
-    if (is.null(data) || nrow(data) == 0) return()
-    groups <- split(data, factor(data$order))
+    if (empty(data)) return(nullGrob())
+    
+    groups <- split(data, factor(data$group))
     grobs <- lapply(groups, function(group) .$draw(group, scales, coordinates, ...))
     
     ggname(paste(.$objname, "s", sep=""), gTree(
