@@ -2,36 +2,42 @@ GeomPath <- proto(Geom, {
   draw_groups <- function(., ...) .$draw(...)
 
   draw <- function(., data, scales, coordinates, arrow = NULL, ...) {
-    if (nrow(data) < 2) return(nullGrob())
-
     munched <- coordinates$munch(data, scales)
 
-    # Work out whether we should use lines or segments
-    g <- split(munched, munched$group)
-    g <- g[sapply(g, nrow) >= 2]
-    munched <- do.call(rbind, g[sapply(g, nrow) >= 2])
-    if (is.null(munched)) return(nullGrob())
+    # Silently drop lines with less than two points, preserving order
+    rows <- ave(seq_len(nrow(munched)), munched$group, FUN = length)
+    munched <- munched[rows >= 2, ]
+    if (nrow(munched) < 2) return(nullGrob())
 
+    # Work out whether we should use lines or segments
+    attr <- ddply(munched, .(group), function(df) {
+      data.frame(
+        solid = identical(unique(df$linetype), 1),
+        constant = nrow(unique(df[, c("colour","size", "linetype")])) == 1
+      )
+    })
+    solid_lines <- all(attr$solid)
+    constant <- all(attr$constant)
+    if (!solid_lines && !constant) {
+      stop("geom_path: If you are using dotted or dashed lines", 
+        ", colour, size and linetype must be constant over the line",
+        call.=FALSE)
+    }
+    
+    # Work out grouping variables for grobs
     n <- nrow(munched)
     group_diff <- munched$group[-1] != munched$group[-n]
     start <- c(TRUE, group_diff)
     end <-   c(group_diff, TRUE)  
     
-    solid_lines <- all(sapply(g, function(df) identical(unique(df$linetype), 1)))
-    constant <- all(sapply(g, function(df) nrow(unique(df[, c("colour", "linetype")])) == 1))
-
-    if (!solid_lines && !constant) {
-      stop("geom_path: If you are using dotted or dashed lines, colour, size and linetype must be constant over the line", call.=FALSE)
-    }
-    
     if (!constant) {
       with(munched, 
         segmentsGrob(
           x[!end], y[!end], x[!start], y[!start],
           default.units="native", arrow = arrow, 
           gp = gpar(
-            col = colour[!end], fill = colour[!end], 
-            lwd = size[!end] * .pt, lty = linetype[!end], lineend = "butt"
+            col = alpha(colour, alpha)[!end], 
+            lwd = size[!end] * .pt, lty = linetype[!end]
           )
         )
       )
@@ -41,7 +47,7 @@ GeomPath <- proto(Geom, {
           x, y, id = as.integer(factor(group)), 
           default.units = "native", arrow = arrow, 
           gp = gpar(
-            col = colour[start], fill = colour[start], 
+            col = alpha(colour, alpha)[start], 
             lwd = size[start] * .pt, lty = linetype[start], lineend = "butt")
         )
       )
@@ -54,7 +60,8 @@ GeomPath <- proto(Geom, {
 
     with(data, 
       ggname(.$my_name(), segmentsGrob(0.1, 0.5, 0.9, 0.5, default.units="npc",
-      gp=gpar(col=colour, lwd=size * .pt, lty=linetype, lineend="butt")))
+      gp=gpar(col=alpha(colour, alpha), lwd=size * .pt, 
+        lty=linetype, lineend="butt")))
     )
   }
   
@@ -63,7 +70,7 @@ GeomPath <- proto(Geom, {
 
   default_stat <- function(.) StatIdentity
   required_aes <- c("x", "y")
-  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1)
+  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = 1)
   icon <- function(.) linesGrob(c(0.2, 0.4, 0.8, 0.6, 0.5), c(0.2, 0.7, 0.4, 0.1, 0.5))
   guide_geom <- function(.) "path"
   
@@ -75,16 +82,16 @@ GeomPath <- proto(Geom, {
 
   examples <- function(.) {
     # Generate data
-    myear <- do.call(rbind, by(movies, movies$year, function(df) data.frame(year=df$year[1], mean.length = mean(df$length), mean.rating=mean(df$rating))))
-    p <- ggplot(myear, aes(x=mean.length, y=mean.rating))
+    myear <- ddply(movies, .(year), colwise(mean, .(length, rating)))
+    p <- ggplot(myear, aes(length, rating))
     p + geom_path()
 
     # Add aesthetic mappings
-    p + geom_path(aes(size=year))
-    p + geom_path(aes(colour=year))
+    p + geom_path(aes(size = year))
+    p + geom_path(aes(colour = year))
     
     # Change scale
-    p + geom_path(aes(size=year)) + scale_size(to=c(1, 3))
+    p + geom_path(aes(size = year)) + scale_size(to = c(1, 3))
 
     # Set aesthetics to fixed value
     p + geom_path(colour = "green")
