@@ -10,12 +10,13 @@ GeomStep <- proto(Geom, {
   }
   details <- "Equivalent to plot(type='s')."
 
-  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1)
+  default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = 1)
   
   draw <- function(., data, scales, coordinates, direction = "hv", ...) {
     data <- stairstep(data, direction)
     GeomPath$draw(data, scales, coordinates, ...)
   }
+  guide_geom <- function(.) "path"
 
   desc_params <- list(
     direction = "direction of stairs: 'vh' for vertical then horizontal, or 'hv' for horizontal then vertical"
