@@ -1,9 +1,11 @@
 GeomSmooth <- proto(Geom, {
   draw <- function(., data, scales, coordinates, ...) {
-    data$fill <- alpha(data$fill, data$alpha)
+    ribbon <- transform(data, colour = NA)
+    path <- transform(data, alpha = 1)
+    
     gList(
-      tryNULL(GeomRibbon$draw(transform(data, colour=NA), scales, coordinates)),
-      GeomPath$draw(rename(data, c(middle = "y")), scales, coordinates)
+      tryNULL(GeomRibbon$draw(ribbon, scales, coordinates)),
+      GeomPath$draw(path, scales, coordinates)
     )
   }
 
@@ -60,7 +62,8 @@ GeomSmooth <- proto(Geom, {
     grid$ucl <- err$fit + 1.96 * err$se.fit
     grid$lcl <- err$fit - 1.96 * err$se.fit
 
-    qplot(wt, mpg, data=mtcars, colour=factor(cyl)) + geom_smooth(aes(min=lcl, max=ucl), data=grid, stat="identity") 
+    qplot(wt, mpg, data=mtcars, colour=factor(cyl)) + 
+      geom_smooth(aes(ymin = lcl, ymax = ucl), data=grid, stat="identity") 
   }
 
 })
