@@ -2,7 +2,15 @@ GeomText <- proto(Geom, {
   draw <- function(., data, scales, coordinates, ...) {
     with(coordinates$transform(data, scales), 
       textGrob(label, x, y, default.units="native", hjust=hjust, vjust=vjust, rot=angle, 
-      gp=gpar(col=colour, fontsize=size * .pt)) 
+      gp=gpar(col=alpha(colour, alpha), fontsize=size * .pt)) 
+    )
+  }
+
+  draw_legend <- function(., data, ...) {
+    data <- aesdefaults(data, .$default_aes(), list(...))
+    with(data,
+      textGrob("a", 0.5, 0.5, rot = angle, 
+      gp=gpar(col=alpha(colour, alpha), fontsize = size * .pt))
     )
   }
 
@@ -12,8 +20,8 @@ GeomText <- proto(Geom, {
   
   default_stat <- function(.) StatIdentity
   required_aes <- c("x", "y", "label")
-  default_aes <- function(.) aes(colour="black", size=5 , angle=0, hjust=0.5, vjust=0.5)
-  guide_geom <- function(x) "line"
+  default_aes <- function(.) aes(colour="black", size=5 , angle=0, hjust=0.5, vjust=0.5, alpha = 1)
+  guide_geom <- function(x) "text"
   
   examples <- function(.) {
     p <- ggplot(mtcars, aes(x=wt, y=mpg, label=rownames(mtcars)))
@@ -34,8 +42,10 @@ GeomText <- proto(Geom, {
     p + geom_text(aes(size=wt)) + scale_size(to=c(3,6))
     
     # Use qplot instead
-    qplot(wt, mpg, data=mtcars, label=rownames(mtcars), geom=c("point","text"))
-    qplot(wt, mpg, data=mtcars, label=rownames(mtcars), geom=c("point","text"), size=wt)
+    qplot(wt, mpg, data = mtcars, label = rownames(mtcars),
+       geom=c("point", "text"))
+    qplot(wt, mpg, data = mtcars, label = rownames(mtcars), size = wt) +
+      geom_text(colour = "red")
   }
   
 })
