@@ -5,7 +5,7 @@ ScaleSize <- proto(ScaleContinuous, expr={
   aliases <- c("scale_area")
   
   
-  new <- function(., name=NULL, limits=NULL, breaks=NULL, labels=NULL, trans = NULL, to = c(0.5, 3)) {
+  new <- function(., name=NULL, limits=NULL, breaks=NULL, labels=NULL, trans = NULL, to = c(1, 6)) {
     .super$new(., name=name, limits=limits, breaks=breaks, labels=labels, trans=trans, variable = "size", to = to)
   }
   
