@@ -17,6 +17,7 @@ geom_crossbar <- GeomCrossbar$build_accessor()
 geom_density <- GeomDensity$build_accessor()
 geom_density2d <- GeomDensity2d$build_accessor()
 geom_errorbar <- GeomErrorbar$build_accessor()
+geom_errorbarh <- GeomErrorbarh$build_accessor()
 geom_freqpoly <- GeomFreqpoly$build_accessor()
 geom_hex <- GeomHex$build_accessor()
 geom_histogram <- GeomHistogram$build_accessor()
@@ -43,6 +44,7 @@ position_fill <- PositionFill$build_accessor()
 position_identity <- PositionIdentity$build_accessor()
 position_jitter <- PositionJitter$build_accessor()
 position_stack <- PositionStack$build_accessor()
+scale_alpha <- ScaleAlpha$build_accessor()
 scale_area <- ScaleArea$build_accessor()
 scale_colour <- ScaleColour$build_accessor()
 scale_colour_brewer <- ScaleBrewer$build_accessor(list(variable = "\"colour\""))
